@@ -10,13 +10,13 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
 use overload "." => "javascriptWorld";
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our %TOOL;
 
@@ -55,94 +55,94 @@ BEGIN {
         },
         scaled => sub {
             my ( $n, $size ) = @_;
-            return ( $n =~ s/%// ) 
-                ? sprintf( '%.f2', $n * $size / 100 )
-                : return sprintf( "%d", $n);
+            return ( $n =~ s/%// )
+              ? sprintf( '%.f2', $n * $size / 100 )
+              : return sprintf( "%d", $n );
         },
         convertColour => sub {
-                my $colour = shift;
-                my %converter = (
-                        '#'    => 'hex2rgb',
-                        'rgb'  => 'rgb2rgb',
-                        'hsl'  => 'hsl2rgb',
-                        'hsv'  => 'hsv2rgb',
-                );
-                my $reg = join '|', reverse sort keys %converter;
-                if ( $colour =~ s/^($reg)// ) {
-                        return $TOOL{$converter{$1}}($colour);
-                }
-                die 'a misserable death';
+            my $colour    = shift;
+            my %converter = (
+                '#'   => 'hex2rgb',
+                'rgb' => 'rgb2rgb',
+                'hsl' => 'hsl2rgb',
+                'hsv' => 'hsv2rgb',
+            );
+            my $reg = join '|', reverse sort keys %converter;
+            if ( $colour =~ s/^($reg)// ) {
+                return $TOOL{ $converter{$1} }($colour);
+            }
+            die 'a misserable death';
         },
         rgb2rgb => sub {
-                return $TOOL{numbers}(shift); 
+            return $TOOL{numbers}(shift);
         },
         hex2rgb => sub {
-             my $hex = shift;
-             my $l = length $hex;
-             return 
-                $l != 6 
-                        ? $l == 3 
-                                ? map { hex( $_ . $_ ) } split //, $hex  
-                                : die 'a misserable death',
-                        : map { hex($_) } $hex =~ /.{2}/g;
+            my $hex = shift;
+            my $l   = length $hex;
+            return
+                $l != 6
+              ? $l == 3
+                  ? map { hex( $_ . $_ ) } split //, $hex
+                  : die 'a misserable death',
+              : map { hex($_) } $hex =~ /.{2}/g;
         },
         hsl2rgb => sub {
-                my ( $h, $s, $l, $a, $m1, $m2 ) = $TOOL{numbers}(shift);
+            my ( $h, $s, $l, $a, $m1, $m2 ) = $TOOL{numbers}(shift);
 
-                $h = ( $h % 360 ) / 360;
-                $s = $TOOL{depercent}($s);
-                $l = $TOOL{depercent}($l);
+            $h = ( $h % 360 ) / 360;
+            $s = $TOOL{depercent}($s);
+            $l = $TOOL{depercent}($l);
 
-                $m2 = $l <= 0.5 ? $l * ( $s + 1 ) : $l + $s - $l * $s;
-                $m1 = $l * 2 - $m2;
+            $m2 = $l <= 0.5 ? $l * ( $s + 1 ) : $l + $s - $l * $s;
+            $m1 = $l * 2 - $m2;
 
-                return (
-                    $TOOL{hue}( $h + 1 / 3, $m1, $m2 ) * 255,
-                    $TOOL{hue}( $h,         $m1, $m2 ) * 255,
-                    $TOOL{hue}( $h - 1 / 3, $m1, $m2 ) * 255, 
-                    ( defined $a ? $a : () ),    
-                );
+            return (
+                $TOOL{hue}( $h + 1 / 3, $m1, $m2 ) * 255,
+                $TOOL{hue}( $h,         $m1, $m2 ) * 255,
+                $TOOL{hue}( $h - 1 / 3, $m1, $m2 ) * 255,
+                ( defined $a ? $a : () ),
+            );
         },
         numbers => sub {
-             return ($_[0] =~ m/([0-9]+)/g);
+            return ( $_[0] =~ m/([0-9]+)/g );
         },
         hsl => sub {
-                my $colour = shift;
-                if (ref \$colour eq 'SCALAR') {
-                    $colour = Colouring::In->new($colour);
-                }
-                my $hsl = $colour->asHSL;
-        		return ($hsl, $colour);
-		},
+            my $colour = shift;
+            if ( ref \$colour eq 'SCALAR' ) {
+                $colour = Colouring::In->new($colour);
+            }
+            my $hsl = $colour->asHSL;
+            return ( $hsl, $colour );
+        },
         hash2array => sub {
-                my $hash = shift;
-                return map { $hash->{$_} } @_;
+            my $hash = shift;
+            return map { $hash->{$_} } @_;
         },
     );
 }
 
 sub javascriptWorld {
-        my ($obj, $meth, @args) = @_;
-        if (ref $meth eq 'ARRAY') { (@args) = @{ $meth }; $meth = shift @args; }
-        return $obj->$meth(@args);
+    my ( $obj, $meth, @args ) = @_;
+    if ( ref $meth eq 'ARRAY' ) { (@args) = @{$meth}; $meth = shift @args; }
+    return $obj->$meth(@args);
 }
 
 sub import {
-		my $caller = caller;
-		{
-			no strict 'refs';
-			for (qw/lighten darken/) {
-				*{"${caller}::${_}"} = \&{"${_[0]}::${_}"};
-			}
-		}
-        eval '{
+    my $caller = caller;
+    {
+        no strict 'refs';
+        for (qw/lighten darken/) {
+            *{"${caller}::${_}"} = \&{"${_[0]}::${_}"};
+        }
+    }
+    eval '{
                 package ' . $caller . ';
                 use AutoLoader;
                 sub AUTOLOAD {
                         my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
                         return [ $method, @_ ];
                 }               
-        }'; #evil
+        }';    #evil
 }
 
 sub rgb {
@@ -162,14 +162,14 @@ sub hsla {
     my ( $self, $h, $s, $l, $a ) = @_;
     my ( $m1, $m2 );
 
-    $h = ( $h % 360 ) / 360;
+    $h  = ( $h % 360 ) / 360;
     $m2 = $l <= 0.5 ? $l * ( $s + 1 ) : $l + $s - $l * $s;
     $m1 = $l * 2 - $m2;
 
     return $self->rgba(
-        $TOOL{scaled}(($TOOL{hue}( $h + 1 / 3, $m1, $m2 ) * 255)),
-        $TOOL{scaled}(($TOOL{hue}( $h,         $m1, $m2 ) * 255)),
-        $TOOL{scaled}(($TOOL{hue}( $h - 1 / 3, $m1, $m2 ) * 255)), 
+        $TOOL{scaled}( ( $TOOL{hue}( $h + 1 / 3, $m1, $m2 ) * 255 ) ),
+        $TOOL{scaled}( ( $TOOL{hue}( $h, $m1, $m2 ) * 255 ) ),
+        $TOOL{scaled}( ( $TOOL{hue}( $h - 1 / 3, $m1, $m2 ) * 255 ) ),
         $a
     );
 }
@@ -187,7 +187,7 @@ sub new {
         $self->{colour} = $rgb;
     }
     elsif ( ref \$rgb eq 'SCALAR' ) {
-        $self->{colour} = [$TOOL{convertColour}($rgb)];
+        $self->{colour} = [ $TOOL{convertColour}($rgb) ];
     }
 
     $self->{alpha} = $TOOL{numIs}($a) ? $a : 1;
@@ -200,7 +200,7 @@ sub toCSS {
 }
 
 sub toRGB {
-    return $_[0]->toRGBA( $_[1] ) if $TOOL{numIs}($_[1]) and $_[1] != 1;
+    return $_[0]->toRGBA( $_[1] ) if $TOOL{numIs}( $_[1] ) and $_[1] != 1;
     return sprintf( 'rgb(%s)', ( $TOOL{joinRgb}( $_[0]->colour ) ) );
 }
 
@@ -253,7 +253,11 @@ sub asHSL {
 sub toHSL {
     my $hsl = $_[0]->asHSL;
 
-    sprintf( "hsl(%s,%s,%s)", $hsl->{h}, $TOOL{percent}($hsl->{s}), $TOOL{percent}($hsl->{l}), );
+    sprintf( "hsl(%s,%s,%s)",
+        $hsl->{h},
+        $TOOL{percent}( $hsl->{s} ),
+        $TOOL{percent}( $hsl->{l} ),
+    );
 }
 
 sub toHSV {
@@ -282,35 +286,33 @@ sub toHSV {
 }
 
 sub lighten {
-        my ($colour, $amt, $meth, $hsl) = @_;
-        
-        ($hsl, $colour) = $TOOL{hsl}($colour);
+    my ( $colour, $amt, $meth, $hsl ) = @_;
 
-		$amt = $TOOL{depercent}($amt);
-        $hsl->{l} += $TOOL{clamp}(
-                ($meth && $meth eq 'relative') 
-                        ? $hsl->{l} * $amt
-                        : $amt,
-                1
-        );
+    ( $hsl, $colour ) = $TOOL{hsl}($colour);
 
-        return $colour->hsla($TOOL{hash2array}($hsl, 'h', 's', 'l', 'a')); 
+    $amt = $TOOL{depercent}($amt);
+    $hsl->{l} += $TOOL{clamp}(
+        ( $meth && $meth eq 'relative' )
+        ? $hsl->{l} * $amt
+        : $amt, 1
+    );
+
+    return $colour->hsla( $TOOL{hash2array}( $hsl, 'h', 's', 'l', 'a' ) );
 }
 
 sub darken {
-        my ($colour, $amt, $meth, $hsl) = @_;
-       
-        ($hsl, $colour) = $TOOL{hsl}($colour);
-       
-		$amt = $TOOL{depercent}($amt);
-        $hsl->{l} -= $TOOL{clamp}(
-                ($meth && $meth eq 'relative') 
-                        ? $hsl->{l} * $amt
-                        : $amt,
-				1,
-        );
+    my ( $colour, $amt, $meth, $hsl ) = @_;
 
-        return $colour->hsla($TOOL{hash2array}($hsl, 'h', 's', 'l', 'a')); 
+    ( $hsl, $colour ) = $TOOL{hsl}($colour);
+
+    $amt = $TOOL{depercent}($amt);
+    $hsl->{l} -= $TOOL{clamp}(
+        ( $meth && $meth eq 'relative' )
+        ? $hsl->{l} * $amt
+        : $amt, 1,
+    );
+
+    return $colour->hsla( $TOOL{hash2array}( $hsl, 'h', 's', 'l', 'a' ) );
 }
 
 sub colour {
